@@ -515,10 +515,10 @@ BUFR tables are located (unless the default path provided by
 bufrread.pl works for you).
 
 For option C<--ahl> the <ahl_regexp> should be a Perl regular
-expression. E.g. C<--ahl 'ISS... ENMI'> will decode only BUFR SHIP
+expression. E.g. C<--ahl "ISS... ENMI"> will decode only BUFR SHIP
 (ISS) from CCCC=ENMI. This is the only case where a little knowledge
-of Perl might be required for using the utility programs included in
-Geo::BUFR.
+of Perl might possibly be required when using the utility programs
+included in Geo::BUFR.
 
 For option C<--param> each line in <descriptor file> should start with
 a BUFR descriptor (6 digits).  Rest of line will be ignored.
